@@ -105,8 +105,10 @@ def clean(trace, folder, docker, attempts=10):
             for item in files + dirs:
                 path = os.path.join(root, item)
                 if not os.access(path, os.W_OK):
-                    # Is the error an access error ?
+                    # shutil.rmtree() will barf on ro files
                     os.chmod(path, stat.S_IWUSR)
+                    # so lets delete it now
+                    os.unlink(path)
     try:
         try:
             shutil.rmtree(folder)
